@@ -1,15 +1,3 @@
-
-
-from __future__ import division
-from __future__ import print_function
-from __future__ import absolute_import
-import matplotlib.pyplot as plt 
-
-from keras.optimizers import Optimizer
-from keras.legacy import interfaces
-from keras import backend as K
-from keras.utils.generic_utils import get_custom_objects
-import timeit
 import numpy as np
 import pandas as pd
 from keras.models import Sequential
@@ -23,19 +11,19 @@ from keras.utils.np_utils import to_categorical # convert to one-hot-encoding
 from keras.models import Sequential
 from keras.initializers import RandomNormal,glorot_normal
 from sklearn.model_selection import StratifiedKFold
+from keras.layers import Activation
 
+from keras import activations
 from keras import backend as K
 from keras import initializers,regularizers,constraints
-from keras.engine import Layer
 from keras.initializers import RandomNormal,glorot_normal
 from keras.layers import Input, Embedding, Dense,concatenate,InputSpec
 from keras.layers import  Activation,concatenate,InputSpec
-from keras.utils import conv_utils,np_utils ,plot_model
-from keras.utils.generic_utils import deserialize_keras_object,has_arg,get_custom_objects
-from keras.utils.generic_utils import deserialize_keras_object
+from keras.utils import conv_utils,np_utils 
+from keras.utils.generic_utils import func_load,deserialize_keras_object,has_arg,get_custom_objects
+from keras.utils.generic_utils import deserialize_keras_object,func_dump
 np.random.seed(7)
-from keras import activations
-
+from keras.engine.base_layer import Layer
 
 
 
@@ -45,7 +33,24 @@ p3=6
 p4=24
 p5=120
 p6=720
-p7=5040
+
+
+
+
+
+def create_model_classic(active1,active2):
+    # create model
+    model = Sequential()
+    model.add(Dense(12, input_dim=8, activation=active1))
+    model.add(Dense(12, activation=active2))
+    model.add(Dense(20))
+    model.add(Dense(1, activation='sigmoid'))
+    # Compile model
+    model.compile(loss='binary_crossentropy', optimizer='adam', metrics=['accuracy'])
+    return model
+
+
+# In[5]:
 
 
 #Defining New Activation functions
@@ -74,6 +79,10 @@ def X_6(x):
     return (K.pow(x,6))/720
 get_custom_objects().update({'X_6': Activation(X_6)})
 
+
+# In[6]:
+
+
 #Defining New Activation functions
 ############################################################################
 def S_X_1(x):
@@ -101,6 +110,10 @@ def S_X_6(x):
 get_custom_objects().update({'S_X_6': Activation(S_X_6)})
 ###############################################################################
 
+
+# In[7]:
+
+
 #Defining New Activation functions
 ############################################################################
 def C_a_X_1(x):
@@ -127,6 +140,10 @@ def C_a_X_6(x):
     return ((32*K.pow(x,6))-(48*K.pow(x,4))+(18*K.pow(x,2))-1)/p6
 get_custom_objects().update({'C_a_X_6': Activation(C_a_X_6)})
 
+
+# In[8]:
+
+
 #Defining New Activation functions
 ############################################################################
 def C_b_X_1(x):
@@ -153,6 +170,10 @@ def C_b_X_6(x):
     return ((64*K.pow(x,4))-(80*K.pow(x,4))+(24*K.pow(x,2))-1)/p6
 get_custom_objects().update({'C_b_X_6': Activation(C_b_X_6)})
 
+
+# In[9]:
+
+
 #Defining New Activation functions
 ############################################################################
 def H_X_1(x):
@@ -179,6 +200,10 @@ def H_X_6(x):
     return ((64*K.pow(x,6))-(480*K.pow(x,4))+(720*K.pow(x,2))-120)/p6
 get_custom_objects().update({'H_X_6': Activation(H_X_6)})
 
+
+# In[10]:
+
+
 #Defining New Activation functions
 ############################################################################
 def L_X_1(x):
@@ -205,12 +230,15 @@ def L_X_6(x):
     return  ((231*K.pow(x,6))-(315*K.pow(x,4))+(105*K.pow(x,2))-5)/(16*p6)
 get_custom_objects().update({'L_X_6': Activation(L_X_6)})
 
-"""### Dense_Co is a custom Keras Layer which we develop to implement SWAG
 
-"""
+# ### Dense_Co is a custom Keras Layer which we develop to implement SWAG
+# 
+
+# In[11]:
+
+
 
 class Dense_Ch_a(Layer):
-    @interfaces.legacy_dense_support
     def __init__(self, units,
                  activation=None,
                  hidden_dim=None,
@@ -255,12 +283,7 @@ class Dense_Ch_a(Layer):
                                       constraint=self.kernel_constraint)
     
     
-        self.kernel1 = self.kernel[:, :self.hidden_dim]
-        self.kernel2 = self.kernel[:, self.hidden_dim: self.hidden_dim * 2]
-        self.kernel3 = self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]
-        self.kernel4 = self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]   
-        self.kernel5 = self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   
-        self.kernel6 = self.kernel[:, self.hidden_dim * 5:]   
+
 
     
     
@@ -278,12 +301,7 @@ class Dense_Ch_a(Layer):
                                         name='bias',
                                         regularizer=self.bias_regularizer,
                                         constraint=self.bias_constraint)
-            self.bias1 = self.bias[:self.hidden_dim]
-            self.bias2 = self.bias[self.hidden_dim: self.hidden_dim * 2]
-            self.bias3 = self.bias[self.hidden_dim * 2: self.hidden_dim * 3]
-            self.bias4 = self.bias[self.hidden_dim * 3: self.hidden_dim * 4]
-            self.bias5 = self.bias[self.hidden_dim * 4: self.hidden_dim * 5]
-            self.bias6 = self.bias[self.hidden_dim * 5:]
+
             
             
 ###########################################################################
@@ -298,21 +316,18 @@ class Dense_Ch_a(Layer):
         self.input_spec = InputSpec(min_ndim=2, axes={-1: input_dim})
         self.built = True
 
+
     def call(self, inputs):
-        output1 = K.dot(inputs, self.kernel1)
-        output2 = K.dot(inputs, self.kernel2) 
-        output3 = K.dot(inputs, self.kernel3)
-        output4 = K.dot(inputs, self.kernel4)
-        output5 = K.dot(inputs, self.kernel5) 
-        output6 = K.dot(inputs, self.kernel6)
- 
-        if self.use_bias:
-            output1 = K.bias_add(output1, self.bias1, data_format='channels_last')
-            output2 = K.bias_add(output2, self.bias2, data_format='channels_last')
-            output3 = K.bias_add(output3, self.bias3, data_format='channels_last')
-            output4 = K.bias_add(output4, self.bias4, data_format='channels_last')
-            output5 = K.bias_add(output5, self.bias5, data_format='channels_last')
-            output6 = K.bias_add(output6, self.bias6, data_format='channels_last')
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
+
+
+
             
         self.activation= activations.get('C_a_X_1')
         output1 = self.activation(output1)
@@ -364,8 +379,14 @@ class Dense_Ch_a(Layer):
         base_config = super(Dense, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
+
+
+
+# In[12]:
+
+
+
 class Dense_Ch_b(Layer):
-    @interfaces.legacy_dense_support
     def __init__(self, units,
                  activation=None,
                  hidden_dim=None,
@@ -410,12 +431,18 @@ class Dense_Ch_b(Layer):
                                       constraint=self.kernel_constraint)
     
     
-        self.kernel1 = self.kernel[:, :self.hidden_dim]
-        self.kernel2 = self.kernel[:, self.hidden_dim: self.hidden_dim * 2]
-        self.kernel3 = self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]
-        self.kernel4 = self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]   
-        self.kernel5 = self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   
-        self.kernel6 = self.kernel[:, self.hidden_dim * 5:]   
+
+    def call(self, inputs):
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
+
+
+
 
     
     
@@ -433,12 +460,8 @@ class Dense_Ch_b(Layer):
                                         name='bias',
                                         regularizer=self.bias_regularizer,
                                         constraint=self.bias_constraint)
-            self.bias1 = self.bias[:self.hidden_dim]
-            self.bias2 = self.bias[self.hidden_dim: self.hidden_dim * 2]
-            self.bias3 = self.bias[self.hidden_dim * 2: self.hidden_dim * 3]
-            self.bias4 = self.bias[self.hidden_dim * 3: self.hidden_dim * 4]
-            self.bias5 = self.bias[self.hidden_dim * 4: self.hidden_dim * 5]
-            self.bias6 = self.bias[self.hidden_dim * 5:]
+
+
             
             
 ###########################################################################
@@ -453,21 +476,19 @@ class Dense_Ch_b(Layer):
         self.input_spec = InputSpec(min_ndim=2, axes={-1: input_dim})
         self.built = True
 
+
     def call(self, inputs):
-        output1 = K.dot(inputs, self.kernel1)
-        output2 = K.dot(inputs, self.kernel2) 
-        output3 = K.dot(inputs, self.kernel3)
-        output4 = K.dot(inputs, self.kernel4)
-        output5 = K.dot(inputs, self.kernel5) 
-        output6 = K.dot(inputs, self.kernel6)
- 
-        if self.use_bias:
-            output1 = K.bias_add(output1, self.bias1, data_format='channels_last')
-            output2 = K.bias_add(output2, self.bias2, data_format='channels_last')
-            output3 = K.bias_add(output3, self.bias3, data_format='channels_last')
-            output4 = K.bias_add(output4, self.bias4, data_format='channels_last')
-            output5 = K.bias_add(output5, self.bias5, data_format='channels_last')
-            output6 = K.bias_add(output6, self.bias6, data_format='channels_last')
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
+
+
+
+
             
         self.activation= activations.get('C_b_X_1')
         output1 = self.activation(output1)
@@ -519,8 +540,14 @@ class Dense_Ch_b(Layer):
         base_config = super(Dense, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
+
+
+
+# In[13]:
+
+
+
 class Dense_S(Layer):
-    @interfaces.legacy_dense_support
     def __init__(self, units,
                  activation=None,
                  hidden_dim=None,
@@ -564,13 +591,6 @@ class Dense_S(Layer):
                                       regularizer=self.kernel_regularizer,
                                       constraint=self.kernel_constraint)
     
-    
-        self.kernel1 = self.kernel[:, :self.hidden_dim]
-        self.kernel2 = self.kernel[:, self.hidden_dim: self.hidden_dim * 2]
-        self.kernel3 = self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]
-        self.kernel4 = self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]   
-        self.kernel5 = self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   
-        self.kernel6 = self.kernel[:, self.hidden_dim * 5:]   
 
     
     
@@ -587,13 +607,7 @@ class Dense_S(Layer):
                                         initializer=self.bias_initializer,
                                         name='bias',
                                         regularizer=self.bias_regularizer,
-                                        constraint=self.bias_constraint)
-            self.bias1 = self.bias[:self.hidden_dim]
-            self.bias2 = self.bias[self.hidden_dim: self.hidden_dim * 2]
-            self.bias3 = self.bias[self.hidden_dim * 2: self.hidden_dim * 3]
-            self.bias4 = self.bias[self.hidden_dim * 3: self.hidden_dim * 4]
-            self.bias5 = self.bias[self.hidden_dim * 4: self.hidden_dim * 5]
-            self.bias6 = self.bias[self.hidden_dim * 5:]
+                                        constraint=self.bias_constrain)
             
             
 ###########################################################################
@@ -608,21 +622,15 @@ class Dense_S(Layer):
         self.input_spec = InputSpec(min_ndim=2, axes={-1: input_dim})
         self.built = True
 
+
     def call(self, inputs):
-        output1 = K.dot(inputs, self.kernel1)
-        output2 = K.dot(inputs, self.kernel2) 
-        output3 = K.dot(inputs, self.kernel3)
-        output4 = K.dot(inputs, self.kernel4)
-        output5 = K.dot(inputs, self.kernel5) 
-        output6 = K.dot(inputs, self.kernel6)
- 
-        if self.use_bias:
-            output1 = K.bias_add(output1, self.bias1, data_format='channels_last')
-            output2 = K.bias_add(output2, self.bias2, data_format='channels_last')
-            output3 = K.bias_add(output3, self.bias3, data_format='channels_last')
-            output4 = K.bias_add(output4, self.bias4, data_format='channels_last')
-            output5 = K.bias_add(output5, self.bias5, data_format='channels_last')
-            output6 = K.bias_add(output6, self.bias6, data_format='channels_last')
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
             
         self.activation= activations.get('S_X_1')
         output1 = self.activation(output1)
@@ -674,8 +682,14 @@ class Dense_S(Layer):
         base_config = super(Dense, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
+
+
+
+# In[14]:
+
+
+
 class Dense_H(Layer):
-    @interfaces.legacy_dense_support
     def __init__(self, units,
                  activation=None,
                  hidden_dim=None,
@@ -720,12 +734,7 @@ class Dense_H(Layer):
                                       constraint=self.kernel_constraint)
     
     
-        self.kernel1 = self.kernel[:, :self.hidden_dim]
-        self.kernel2 = self.kernel[:, self.hidden_dim: self.hidden_dim * 2]
-        self.kernel3 = self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]
-        self.kernel4 = self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]   
-        self.kernel5 = self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   
-        self.kernel6 = self.kernel[:, self.hidden_dim * 5:]   
+
 
     
     
@@ -743,12 +752,7 @@ class Dense_H(Layer):
                                         name='bias',
                                         regularizer=self.bias_regularizer,
                                         constraint=self.bias_constraint)
-            self.bias1 = self.bias[:self.hidden_dim]
-            self.bias2 = self.bias[self.hidden_dim: self.hidden_dim * 2]
-            self.bias3 = self.bias[self.hidden_dim * 2: self.hidden_dim * 3]
-            self.bias4 = self.bias[self.hidden_dim * 3: self.hidden_dim * 4]
-            self.bias5 = self.bias[self.hidden_dim * 4: self.hidden_dim * 5]
-            self.bias6 = self.bias[self.hidden_dim * 5:]
+
             
             
 ###########################################################################
@@ -763,21 +767,18 @@ class Dense_H(Layer):
         self.input_spec = InputSpec(min_ndim=2, axes={-1: input_dim})
         self.built = True
 
+
     def call(self, inputs):
-        output1 = K.dot(inputs, self.kernel1)
-        output2 = K.dot(inputs, self.kernel2) 
-        output3 = K.dot(inputs, self.kernel3)
-        output4 = K.dot(inputs, self.kernel4)
-        output5 = K.dot(inputs, self.kernel5) 
-        output6 = K.dot(inputs, self.kernel6)
- 
-        if self.use_bias:
-            output1 = K.bias_add(output1, self.bias1, data_format='channels_last')
-            output2 = K.bias_add(output2, self.bias2, data_format='channels_last')
-            output3 = K.bias_add(output3, self.bias3, data_format='channels_last')
-            output4 = K.bias_add(output4, self.bias4, data_format='channels_last')
-            output5 = K.bias_add(output5, self.bias5, data_format='channels_last')
-            output6 = K.bias_add(output6, self.bias6, data_format='channels_last')
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
+
+
+
             
         self.activation= activations.get('H_X_1')
         output1 = self.activation(output1)
@@ -829,8 +830,14 @@ class Dense_H(Layer):
         base_config = super(Dense, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
+
+
+
+# In[15]:
+
+
+
 class Dense_L(Layer):
-    @interfaces.legacy_dense_support
     def __init__(self, units,
                  activation=None,
                  hidden_dim=None,
@@ -875,12 +882,7 @@ class Dense_L(Layer):
                                       constraint=self.kernel_constraint)
     
     
-        self.kernel1 = self.kernel[:, :self.hidden_dim]
-        self.kernel2 = self.kernel[:, self.hidden_dim: self.hidden_dim * 2]
-        self.kernel3 = self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]
-        self.kernel4 = self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]   
-        self.kernel5 = self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   
-        self.kernel6 = self.kernel[:, self.hidden_dim * 5:]   
+  
 
     
     
@@ -898,12 +900,7 @@ class Dense_L(Layer):
                                         name='bias',
                                         regularizer=self.bias_regularizer,
                                         constraint=self.bias_constraint)
-            self.bias1 = self.bias[:self.hidden_dim]
-            self.bias2 = self.bias[self.hidden_dim: self.hidden_dim * 2]
-            self.bias3 = self.bias[self.hidden_dim * 2: self.hidden_dim * 3]
-            self.bias4 = self.bias[self.hidden_dim * 3: self.hidden_dim * 4]
-            self.bias5 = self.bias[self.hidden_dim * 4: self.hidden_dim * 5]
-            self.bias6 = self.bias[self.hidden_dim * 5:]
+
             
             
 ###########################################################################
@@ -918,21 +915,18 @@ class Dense_L(Layer):
         self.input_spec = InputSpec(min_ndim=2, axes={-1: input_dim})
         self.built = True
 
+
     def call(self, inputs):
-        output1 = K.dot(inputs, self.kernel1)
-        output2 = K.dot(inputs, self.kernel2) 
-        output3 = K.dot(inputs, self.kernel3)
-        output4 = K.dot(inputs, self.kernel4)
-        output5 = K.dot(inputs, self.kernel5) 
-        output6 = K.dot(inputs, self.kernel6)
- 
-        if self.use_bias:
-            output1 = K.bias_add(output1, self.bias1, data_format='channels_last')
-            output2 = K.bias_add(output2, self.bias2, data_format='channels_last')
-            output3 = K.bias_add(output3, self.bias3, data_format='channels_last')
-            output4 = K.bias_add(output4, self.bias4, data_format='channels_last')
-            output5 = K.bias_add(output5, self.bias5, data_format='channels_last')
-            output6 = K.bias_add(output6, self.bias6, data_format='channels_last')
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
+
+
+
             
         self.activation= activations.get('L_X_1')
         output1 = self.activation(output1)
@@ -987,9 +981,23 @@ class Dense_L(Layer):
 
 
 
+# In[ ]:
+
+
+
+
+
+# In[ ]:
+
+
+
+
+
+# In[16]:
+
+
 
 class Dense_Co(Layer):
-    @interfaces.legacy_dense_support
     def __init__(self, units,
                  activation=None,
                  hidden_dim=None,
@@ -1034,12 +1042,7 @@ class Dense_Co(Layer):
                                       constraint=self.kernel_constraint)
     
     
-        self.kernel1 = self.kernel[:, :self.hidden_dim]
-        self.kernel2 = self.kernel[:, self.hidden_dim: self.hidden_dim * 2]
-        self.kernel3 = self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]
-        self.kernel4 = self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]   
-        self.kernel5 = self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   
-        self.kernel6 = self.kernel[:, self.hidden_dim * 5:]   
+  
 
     
     
@@ -1057,12 +1060,7 @@ class Dense_Co(Layer):
                                         name='bias',
                                         regularizer=self.bias_regularizer,
                                         constraint=self.bias_constraint)
-            self.bias1 = self.bias[:self.hidden_dim]
-            self.bias2 = self.bias[self.hidden_dim: self.hidden_dim * 2]
-            self.bias3 = self.bias[self.hidden_dim * 2: self.hidden_dim * 3]
-            self.bias4 = self.bias[self.hidden_dim * 3: self.hidden_dim * 4]
-            self.bias5 = self.bias[self.hidden_dim * 4: self.hidden_dim * 5]
-            self.bias6 = self.bias[self.hidden_dim * 5:]
+
             
             
 ###########################################################################
@@ -1077,21 +1075,18 @@ class Dense_Co(Layer):
         self.input_spec = InputSpec(min_ndim=2, axes={-1: input_dim})
         self.built = True
 
+
     def call(self, inputs):
-        output1 = K.dot(inputs, self.kernel1)
-        output2 = K.dot(inputs, self.kernel2) 
-        output3 = K.dot(inputs, self.kernel3)
-        output4 = K.dot(inputs, self.kernel4)
-        output5 = K.dot(inputs, self.kernel5) 
-        output6 = K.dot(inputs, self.kernel6)
- 
-        if self.use_bias:
-            output1 = K.bias_add(output1, self.bias1, data_format='channels_last')
-            output2 = K.bias_add(output2, self.bias2, data_format='channels_last')
-            output3 = K.bias_add(output3, self.bias3, data_format='channels_last')
-            output4 = K.bias_add(output4, self.bias4, data_format='channels_last')
-            output5 = K.bias_add(output5, self.bias5, data_format='channels_last')
-            output6 = K.bias_add(output6, self.bias6, data_format='channels_last')
+         
+        output1 = K.bias_add(K.dot(inputs, self.kernel[:, :self.hidden_dim]), self.bias[:self.hidden_dim], data_format='channels_last')
+        output2 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim: self.hidden_dim * 2]), self.bias[self.hidden_dim: self.hidden_dim * 2], data_format='channels_last')
+        output3 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 2: self.hidden_dim * 3]), self.bias[self.hidden_dim * 2: self.hidden_dim * 3], data_format='channels_last')
+        output4 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 3: self.hidden_dim * 4]), self.bias[self.hidden_dim * 3: self.hidden_dim * 4], data_format='channels_last')
+        output5 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 4: self.hidden_dim * 5]   ) , self.bias[self.hidden_dim * 4: self.hidden_dim * 5], data_format='channels_last')
+        output6 = K.bias_add(K.dot(inputs, self.kernel[:, self.hidden_dim * 5:] ), self.bias[self.hidden_dim * 5:], data_format='channels_last')
+
+
+
             
         self.activation= activations.get('X_1')
         output1 = self.activation(output1)
@@ -1143,11 +1138,11 @@ class Dense_Co(Layer):
         base_config = super(Dense, self).get_config()
         return dict(list(base_config.items()) + list(config.items()))
 
-"""### Define normalize Functions
 
-### Define Rescaling Functions from 0-1 to 0.1-0.9
 
-"""
+
+# In[17]:
+
 
 #Define normalize Functions
 def normalize(d):
@@ -1163,11 +1158,9 @@ def rescale_range(d):
     d=np.add(d, 0.01)
     return d
 
-"""### This method compiles a Keras model and return it.
-### input_dim is the dimension of input and  output_dim is the dimension of output.
-### In our model image the number of Green, Red, and Blue are equal, and we show them by hidden_dim
-### by default hidden_dim = input_dim but we can change it.
-"""
+
+# In[18]:
+
 
 def build_model_v1(input_dim,hidden_dim,output_dim):
     model = Sequential()
